
Input rejection
-------

**Description:**

Whenever the application detects malicious or unexpected userinput you want to make sure 
the application actual rejects the submitted userinput rather than direclty proccess it. 


**Solution:**

Verify that the application actual rejects, sanitise or format your userinput into not 
malicious data. 

	